@@ -4,8 +4,12 @@ import requests
 
 
 class Newton:
-    def __init__(self, api_key):
+    def __init__(self, api_key, mode="prod"):
         self.api_base = "https://api.objectways.com/v1"
+
+        if mode == "test":
+            self.api.base = "https://devapi.objectways.com/v1"
+            
         self.__headers = {"Content-Type": "application/json", "api_key": api_key}
 
     @staticmethod
